class Configuration:
    FILTER_QT_WARNINGS = True
    COMMUNICATOR_TRACE = False
    TRACE_EXEC_OPTION = False
    TIMER_PULSE = 0.1
    NOSHOW = False
    DROP_COMMUNICATOR_INVALIDE_DATA = True